@@ -1,9 +1,10 @@
 #!/usr/bin/env python
 from __future__ import print_function
+__version__ = "1.0.4"
 
 import os
 import json
-from os.path import abspath, isfile, join, expanduser, dirname
+from os.path import abspath, isfile, join, expanduser
 from base64 import standard_b64encode
 
 try:
@@ -17,11 +18,6 @@ TINY_URL = "http://api.tinypng.org/api/shrink"
 _invalid_keys = set()
 
 
-def get_version():
-    ver_file = join(dirname(__file__), 'VERSION')
-    return open(ver_file).read()
-
-
 def find_keys(opts=None, args=None):
     """Get keys specified in arguments
 
